'use strict';

var _slicedToArray2 = require('babel-runtime/helpers/slicedToArray');

var _slicedToArray3 = _interopRequireDefault(_slicedToArray2);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var os = require('os');

var _require = require('@commitlint/test'),
    git = _require.git;

var test = require('ava');
var execa = require('execa');
var which = require('which');

var NODE_BIN = which.sync('node');
var BIN = require.resolve('../lib/cli.js');

var TRAVIS_COMMITLINT_BIN = require.resolve('../fixtures/commitlint');
var TRAVIS_COMMITLINT_GIT_BIN = require.resolve('../fixtures/git');
var TRAVIS_BRANCH = 'TRAVIS_BRANCH';
var TRAVIS_COMMIT = 'TRAVIS_COMMIT';

var bin = function bin() {
	var $args = arguments;return new Promise(function ($return, $error) {
		var config;
		config = $args.length > 0 && $args[0] !== undefined ? $args[0] : {};
		var $Try_1_Post = function () {
			try {
				return $return();
			} catch ($boundEx) {
				return $error($boundEx);
			}
		}.bind(this);var $Try_1_Catch = function (err) {
			try {
				throw new Error([err.stdout, err.stderr].join('\n'));
			} catch ($boundEx) {
				return $error($boundEx);
			}
		}.bind(this);
		try {
			return Promise.resolve(execa(BIN, Object.assign({ extendEnv: false }, config))).then($return, $Try_1_Catch);
		} catch (err) {
			$Try_1_Catch(err)
		}
	}.bind(this));
};

test('should throw when not on travis ci', function (t) {
	return new Promise(function ($return, $error) {
		var env;

		env = {
			CI: false,
			TRAVIS: false
		};

		return Promise.resolve(t.throws(bin({ env }), /@commitlint\/travis-cli is inteded to be used on Travis CI/)).then(function ($await_3) {
			try {
				return $return();
			} catch ($boundEx) {
				return $error($boundEx);
			}
		}.bind(this), $error);
	}.bind(this));
});

test.failing('should throw when on travis ci, but env vars are missing', function (t) {
	return new Promise(function ($return, $error) {
		var env;

		env = {
			TRAVIS: true,
			CI: true
		};

		return Promise.resolve(t.throws(bin({ env }), /TRAVIS_COMMIT, TRAVIS_BRANCH/)).then(function ($await_4) {
			try {
				return $return();
			} catch ($boundEx) {
				return $error($boundEx);
			}
		}.bind(this), $error);
	}.bind(this));
});

test('should throw when on travis ci, but TRAVIS_COMMIT is missing', function (t) {
	return new Promise(function ($return, $error) {
		var env;

		env = {
			TRAVIS: true,
			CI: true
		};

		return Promise.resolve(t.throws(bin({ env }), /TRAVIS_COMMIT/)).then(function ($await_5) {
			try {
				return $return();
			} catch ($boundEx) {
				return $error($boundEx);
			}
		}.bind(this), $error);
	}.bind(this));
});

test.failing('should throw when on travis ci, but TRAVIS_BRANCH is missing', function (t) {
	return new Promise(function ($return, $error) {
		var env;

		env = {
			TRAVIS: true,
			CI: true
		};

		return Promise.resolve(t.throws(bin({ env }), /TRAVIS_BRANCH/)).then(function ($await_6) {
			try {
				return $return();
			} catch ($boundEx) {
				return $error($boundEx);
			}
		}.bind(this), $error);
	}.bind(this));
});

test.failing('should call git with expected args on shallow repo', function (t) {
	return new Promise(function ($return, $error) {
		var cwd, env, result, invocations, _invocations, stash, branches, unshallow, checkout, back, pop, commilint;

		if (os.platform() === 'win32') {
			t.pass();
			return $return();
		}

		return Promise.resolve(git.clone('https://github.com/marionebl/commitlint.git', ['--depth=10'])).then(function ($await_7) {
			try {
				cwd = $await_7;

				env = {
					TRAVIS: true,
					CI: true,
					TRAVIS_BRANCH,
					TRAVIS_COMMIT,
					TRAVIS_COMMITLINT_BIN,
					TRAVIS_COMMITLINT_GIT_BIN
				};

				return Promise.resolve(bin({ cwd, env })).then(function ($await_8) {
					try {
						result = $await_8;
						return Promise.resolve(getInvocations(result.stdout)).then(function ($await_9) {
							try {
								invocations = $await_9;
								t.is(invocations.length, 7);

								_invocations = (0, _slicedToArray3.default)(invocations, 7), stash = _invocations[0], branches = _invocations[1], unshallow = _invocations[2], checkout = _invocations[3], back = _invocations[4], pop = _invocations[5], commilint = _invocations[6];


								t.deepEqual(stash, [NODE_BIN, TRAVIS_COMMITLINT_GIT_BIN, 'stash']);
								t.deepEqual(branches, [NODE_BIN, TRAVIS_COMMITLINT_GIT_BIN, 'remote', 'set-branches', 'origin', TRAVIS_BRANCH]);
								t.deepEqual(unshallow, [NODE_BIN, TRAVIS_COMMITLINT_GIT_BIN, 'fetch', '--unshallow', '--quiet']);
								t.deepEqual(checkout, [NODE_BIN, TRAVIS_COMMITLINT_GIT_BIN, 'checkout', TRAVIS_BRANCH, '--quiet']);
								t.deepEqual(back, [NODE_BIN, TRAVIS_COMMITLINT_GIT_BIN, 'checkout', '-', '--quiet']);
								t.deepEqual(pop, [NODE_BIN, TRAVIS_COMMITLINT_GIT_BIN, 'stash', 'pop']);
								t.deepEqual(commilint, [NODE_BIN, TRAVIS_COMMITLINT_BIN, '--from', TRAVIS_BRANCH, '--to', TRAVIS_COMMIT]);
								return $return();
							} catch ($boundEx) {
								return $error($boundEx);
							}
						}.bind(this), $error);
					} catch ($boundEx) {
						return $error($boundEx);
					}
				}.bind(this), $error);
			} catch ($boundEx) {
				return $error($boundEx);
			}
		}.bind(this), $error);
	}.bind(this));
});

test.failing('should call git with expected args on unshallow repo', function (t) {
	return new Promise(function ($return, $error) {
		var cwd, env, result, invocations, _invocations2, stash, branches, checkout, back, pop, commilint;

		if (os.platform() === 'win32') {
			t.pass();
			return $return();
		}

		return Promise.resolve(git.clone('https://github.com/marionebl/commitlint.git')).then(function ($await_10) {
			try {
				cwd = $await_10;

				env = {
					TRAVIS: true,
					CI: true,
					TRAVIS_BRANCH,
					TRAVIS_COMMIT,
					TRAVIS_COMMITLINT_BIN,
					TRAVIS_COMMITLINT_GIT_BIN
				};

				return Promise.resolve(bin({ cwd, env })).then(function ($await_11) {
					try {
						result = $await_11;
						return Promise.resolve(getInvocations(result.stdout)).then(function ($await_12) {
							try {
								invocations = $await_12;
								t.is(invocations.length, 6);

								_invocations2 = (0, _slicedToArray3.default)(invocations, 6), stash = _invocations2[0], branches = _invocations2[1], checkout = _invocations2[2], back = _invocations2[3], pop = _invocations2[4], commilint = _invocations2[5];


								t.deepEqual(stash, [NODE_BIN, TRAVIS_COMMITLINT_GIT_BIN, 'stash']);
								t.deepEqual(branches, [NODE_BIN, TRAVIS_COMMITLINT_GIT_BIN, 'remote', 'set-branches', 'origin', TRAVIS_BRANCH]);
								t.deepEqual(checkout, [NODE_BIN, TRAVIS_COMMITLINT_GIT_BIN, 'checkout', TRAVIS_BRANCH, '--quiet']);
								t.deepEqual(back, [NODE_BIN, TRAVIS_COMMITLINT_GIT_BIN, 'checkout', '-', '--quiet']);
								t.deepEqual(pop, [NODE_BIN, TRAVIS_COMMITLINT_GIT_BIN, 'stash', 'pop']);
								t.deepEqual(commilint, [NODE_BIN, TRAVIS_COMMITLINT_BIN, '--from', TRAVIS_BRANCH, '--to', TRAVIS_COMMIT]);
								return $return();
							} catch ($boundEx) {
								return $error($boundEx);
							}
						}.bind(this), $error);
					} catch ($boundEx) {
						return $error($boundEx);
					}
				}.bind(this), $error);
			} catch ($boundEx) {
				return $error($boundEx);
			}
		}.bind(this), $error);
	}.bind(this));
});

function getInvocations(stdout) {
	var matches = stdout.match(/[^[\]]+/g);
	var raw = Array.isArray(matches) ? matches : [];

	return raw.filter(function (invocation) {
		return invocation !== '\n';
	}).map(function (invocation) {
		return invocation.split(',').map(function (fragment) {
			return fragment.trim();
		}).map(function (fragment) {
			return fragment.substring(1, fragment.length - 1);
		}).filter(Boolean);
	});
}
//# sourceMappingURL=cli.test.js.map